@@ -149,7 +149,7 @@ class TextOp(object):
     def __repr__(self):
         rops = []
         for op,args,kwargs in self.ops:
-            opargs = map(repr,args)
+            opargs = [ '%r' % v if isinstance(v,(basestring,int,float)) else v for v in args ]
             opargs += [ '%s=%r' % (k,v) for k,v in kwargs.items() ]
             rops.append('%s(%s)' % (op,','.join(map(str,opargs))))
         return '.'.join(rops)
@@ -755,8 +755,10 @@ class ListExt(list):
         return self
     def __getslice__(self,*args, **kwargs):
         return extend_type(super(ListExt, self).__getslice__(*args, **kwargs))
-    def __getitem__(self,*args, **kwargs):
-        return extend_type(super(ListExt, self).__getitem__(*args, **kwargs))
+    def __getitem__(self,key,*args, **kwargs):
+        if key < 0 or key >= len(self):
+            return NoAttr
+        return extend_type(super(ListExt, self).__getitem__(key,*args, **kwargs))
     def __add__(self,*args, **kwargs):
         return extend_type(super(ListExt, self).__add__(*args, **kwargs))
     def __mul__(self,*args, **kwargs):
